@@ -12,6 +12,7 @@ conf_flags="--enable-debug --with-debug"
 DIE=0
 libtool=0
 gettext=0
+run_automake=0
 libtoolize=libtoolize
 
 if which glibtoolize >/dev/null 2>&1 ; then
@@ -26,14 +27,15 @@ missing() {
   DIE=1
 }
 
-(autoconf --version) < /dev/null > /dev/null 2>&1 || missing autoconf
 (aclocal --version) < /dev/null > /dev/null 2>&1 || missing aclocal
+(autoconf --version) < /dev/null > /dev/null 2>&1 || missing autoconf
 
-grep "^AM_GNU_GETTEXT" $srcdir/configure.in >/dev/null && gettext=1
-grep "^AC_PROG_LIBTOOL" $srcdir/configure.in >/dev/null && libtool=1
+grep "^AM_GNU_GETTEXT" $srcdir/configure.ac >/dev/null && gettext=1
+grep "^AC_PROG_LIBTOOL" $srcdir/configure.ac >/dev/null && libtool=1
+grep "^AM_INIT_AUTOMAKE" $srcdir/configure.ac >/dev/null && run_automake=1
 
 if test "$gettext" -eq 1; then
-  grep "sed.*POTFILES" $srcdir/configure.in >/dev/null || \
+  grep "sed.*POTFILES" $srcdir/configure.ac >/dev/null || \
   (gettextize --version) < /dev/null > /dev/null 2>&1 || missing gettext
 fi
 
@@ -72,6 +74,12 @@ autoheader
 echo "Running autoconf ..."
 autoconf
 
+if test  "$run_automake" -eq 1; then
+  echo "Running automake..."
+  automake --add-missing --foreign --force --copy
+fi
+
+
 if test x$NOCONFIGURE = x; then
   echo Running $srcdir/configure $conf_flags "$@" ...
   $srcdir/configure $conf_flags "$@" \
@@ -82,5 +90,5 @@ fi
 
 if which jade >/dev/null; then
 	echo "Generate documentation ..."
-	(cd doc && make)
+	(cd doc && make doc)
 fi
