@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mail_cache_db.c,v 1.19 2005/06/01 16:04:41 hoa Exp $
+ * $Id: mail_cache_db.c,v 1.20 2006/05/22 13:39:40 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mail_cache_db.h"
 
 #include <sys/types.h>
@@ -41,11 +45,6 @@
 #include <stdlib.h>
 #include <string.h>
 
-#ifndef CONFIG_H
-#define CONFIG_H
-#include "config.h"
-#endif
-
 #include "libetpan-config.h"
 
 #include "maillock.h"
