@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maillock.c,v 1.15 2006/08/05 02:34:06 hoa Exp $
+ * $Id: maillock.c,v 1.16 2007/07/12 14:38:47 smarinier Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -163,6 +163,26 @@ static int lock_common(const char * filename, int fd, short locktype)
   time_t start;
 
   /* SEB try implementation */
+#ifdef SEB_TRY
+  int reslock;
+
+  lseek( fd, 0L, SEEK_SET );
+  reslock = _locking( fd, _LK_NBLCK, LONG_MAX);
+  if (reslock == 0) return 0;
+  if (errno != EACCES) return -1;
+
+  time(&start);
+
+  while (1) {
+    time_t now;
+	sleep( 5);
+	reslock = _locking( fd, _LK_NBLCK, LONG_MAX);
+  if (reslock == 0) return 0;
+  if (errno != EACCES) return -1;
+	time(&now);
+    if (now > start + LOCKTO_GLOB) {
+		return -1;
+#else /* SEB_TRY */
   if (fd != -1) {
     lseek( fd, 0L, SEEK_SET );
     if (_locking( fd, _LK_NBLCK, LONG_MAX) == 0) return 0;
@@ -177,10 +197,12 @@ static int lock_common(const char * filename, int fd, short locktype)
       if (now > start + LOCKTO_GLOB) {
         return -1;
       }
-    }
+#endif // SEBTRY
+	}
   }
+  return 0;	/* SEB 20070709 */
   
-#else
+#else /* WIN32 */
   char lockfilename[PATH_MAX];
 #ifndef HAVE_LIBLOCKFILE
   struct flock lock;
@@ -188,7 +210,7 @@ static int lock_common(const char * filename, int fd, short locktype)
   int statfailed = 0;
   time_t start;
   int r;
-#endif
+#endif /* HAVE_LIBLOCKFILE */
   int res;
 
   /* dot lock file */
@@ -284,7 +306,7 @@ static int lock_common(const char * filename, int fd, short locktype)
       /* WARNING POSIX lock could not be applied */
     }
   }
-#endif
+#endif /* HAVE_LIBLOCKFILE */
  err:
   return res;
 #endif /* WIN32 */
