@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailstream.c,v 1.18 2006/06/28 06:13:47 skunk Exp $
+ * $Id: mailstream.c,v 1.19 2006/12/22 18:45:44 hoa Exp $
  */
 
 #include "mailstream.h"
@@ -42,61 +42,6 @@
 
 #define DEFAULT_NETWORK_TIMEOUT 300
 
-#if 0
-#ifdef LIBETPAN_MAILSTREAM_DEBUG
-
-#define STREAM_DEBUG
-
-#include <stdio.h>
-
-#define LOG_FILE "libetpan-stream-debug.log"
-
-int mailstream_debug = 0;
-
-#define STREAM_LOG_BUF(buf, size) \
-  if (mailstream_debug) { \
-    FILE * f; \
-    mode_t old_mask; \
-    \
-    old_mask = umask(0077); \
-    f = fopen(LOG_FILE, "a"); \
-    umask(old_mask); \
-    if (f != NULL) { \
-      maillock_write_lock(LOG_FILE, fileno(f)); \
-      fwrite((buf), 1, (size), f); \
-      maillock_write_unlock(LOG_FILE, fileno(f)); \
-      fclose(f); \
-    } \
-  }
-
-#define STREAM_LOG(str) \
-  if (mailstream_debug) { \
-    FILE * f; \
-    mode_t old_mask; \
-    \
-    old_mask = umask(0077); \
-    f = fopen(LOG_FILE, "a"); \
-    umask(old_mask); \
-    if (f != NULL) { \
-      maillock_write_lock(LOG_FILE, fileno(f)); \
-      fputs((str), f); \
-      maillock_write_unlock(LOG_FILE, fileno(f)); \
-      fclose(f); \
-    } \
-  }
-
-#else
-
-#define STREAM_LOG_BUF(buf, size) do { } while (0)
-#define STREAM_LOG(buf) do { } while (0)
-
-#endif
-#endif
-
-#define STREAM_LOG_BUF(buf, size) do { } while (0)
-#define STREAM_LOG(buf) do { } while (0)
-
-
 mailstream * mailstream_new(mailstream_low * low, size_t buffer_size)
 {
   mailstream * s;
@@ -178,13 +123,6 @@ ssize_t mailstream_write(mailstream * s, const void * buf, size_t count)
       return write_direct(s, buf, count);
   }
 
-#ifdef STREAM_DEBUG
-  STREAM_LOG(">>>>>>> send >>>>>>\n");
-  STREAM_LOG_BUF(buf, count);
-  STREAM_LOG("\n");
-  STREAM_LOG(">>>>>>> end send >>>>>>\n");
-#endif
-
   return write_to_internal_buffer(s, buf, count);
 }
 
@@ -278,13 +216,6 @@ ssize_t mailstream_read(mailstream * s, void * buf, size_t count)
   left -= read_bytes;
 
   if (left == 0) {
-#ifdef STREAM_DEBUG
-    STREAM_LOG("<<<<<<< read <<<<<<\n");
-    STREAM_LOG_BUF(buf, read_bytes);
-    STREAM_LOG("\n");
-    STREAM_LOG("<<<<<<< end read <<<<<<\n");
-#endif
-
     return read_bytes;
   }
 
@@ -294,14 +225,6 @@ ssize_t mailstream_read(mailstream * s, void * buf, size_t count)
       if (count == left)
 	return -1;
       else {
-
-#ifdef STREAM_DEBUG
-        STREAM_LOG("<<<<<<< read <<<<<<\n");
-        STREAM_LOG_BUF(buf, count - left);
-        STREAM_LOG("\n");
-        STREAM_LOG("<<<<<<< end read <<<<<<\n");
-#endif
-
 	return count - left;
       }
     }
@@ -309,13 +232,6 @@ ssize_t mailstream_read(mailstream * s, void * buf, size_t count)
     cur_buf += read_bytes;
     left -= read_bytes;
 
-#ifdef STREAM_DEBUG
-    STREAM_LOG("<<<<<<< read <<<<<<\n");
-    STREAM_LOG_BUF(buf, count - left);
-    STREAM_LOG("\n");
-    STREAM_LOG("<<<<<<< end read <<<<<<\n");
-#endif
-
     return count - left;
   }
 
@@ -324,13 +240,6 @@ ssize_t mailstream_read(mailstream * s, void * buf, size_t count)
     if (left == count)
       return -1;
     else {
-#ifdef STREAM_DEBUG
-      STREAM_LOG("<<<<<<< read <<<<<<\n");
-      STREAM_LOG_BUF(buf, count - left);
-      STREAM_LOG("\n");
-      STREAM_LOG("<<<<<<< end read <<<<<<\n");
-#endif
-      
       return count - left;
     }
   }
@@ -341,13 +250,6 @@ ssize_t mailstream_read(mailstream * s, void * buf, size_t count)
   cur_buf += read_bytes;
   left -= read_bytes;
 
-#ifdef STREAM_DEBUG
-  STREAM_LOG("<<<<<<< read <<<<<<\n");
-  STREAM_LOG_BUF(buf, count - left);
-  STREAM_LOG("\n");
-  STREAM_LOG("<<<<<<< end read <<<<<<\n");
-#endif
-
   return count - left;
 }
 
@@ -394,10 +296,13 @@ ssize_t mailstream_feed_read_buffer(mailstream * s)
   return s->read_buffer_len;
 }
 
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
+void mailstream_cancel(mailstream * s)
+{
+  if (s == NULL)
+    return;
+  
+  mailstream_low_cancel(s->low);
+}
+
 struct timeval mailstream_network_delay =
 {  DEFAULT_NETWORK_TIMEOUT, 0 };
-#else
-struct timeval mailstream_network_delay =
-  { .tv_sec = DEFAULT_NETWORK_TIMEOUT, .tv_usec = 0 };
-#endif
