@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailstream_ssl.c,v 1.50 2007/01/07 22:29:48 hoa Exp $
+ * $Id: mailstream_ssl.c,v 1.57 2007/07/30 09:35:26 colinleroy Exp $
  */
 
 /*
@@ -80,7 +80,9 @@
 #  include <gnutls/x509.h>
 # endif
 # ifdef LIBETPAN_REENTRANT
-#  include <pthread.h>
+#	if HAVE_PTHREAD_H
+#	  include <pthread.h>
+#	endif
 # endif
 #endif
 
@@ -105,7 +107,19 @@ struct mailstream_ssl_data {
 
 #ifdef USE_SSL
 #ifdef LIBETPAN_REENTRANT
-static pthread_mutex_t ssl_lock = PTHREAD_MUTEX_INITIALIZER;
+#	ifdef WIN32
+#		define MUTEX_LOCK(x) {if (!_init_lock) {_init_lock=1; InitializeCriticalSection( x);} EnterCriticalSection(x);}
+#		define MUTEX_UNLOCK(x) {if (!_init_lock) {_init_lock=1; InitializeCriticalSection( x);} LeaveCriticalSection(x); }
+		static CRITICAL_SECTION ssl_lock;
+		static int _init_lock = 0;
+#	else
+#		define MUTEX_LOCK(x) pthread_mutex_lock(x)
+#		define MUTEX_UNLOCK(x) pthread_mutex_unlock(x)
+		static pthread_mutex_t ssl_lock = PTHREAD_MUTEX_INITIALIZER;
+#	endif
+#else
+#	define MUTEX_LOCK(x)
+#	define MUTEX_UNLOCK(x)
 #endif
 static int gnutls_init_done = 0;
 static int openssl_init_done = 0;
@@ -114,26 +128,18 @@ static int openssl_init_done = 0;
 void mailstream_gnutls_init_not_required(void)
 {
 #ifdef USE_SSL
-#ifdef LIBETPAN_REENTRANT
-  pthread_mutex_lock(&ssl_lock);
-#endif
+  MUTEX_LOCK(&ssl_lock);
   gnutls_init_done = 1;
-#ifdef LIBETPAN_REENTRANT
-  pthread_mutex_unlock(&ssl_lock);
-#endif
+  MUTEX_UNLOCK(&ssl_lock);
 #endif
 }
 
 void mailstream_openssl_init_not_required(void)
 {
 #ifdef USE_SSL
-#ifdef LIBETPAN_REENTRANT
-  pthread_mutex_lock(&ssl_lock);
-#endif
+  MUTEX_LOCK(&ssl_lock);
   openssl_init_done = 1;
-#ifdef LIBETPAN_REENTRANT
-  pthread_mutex_unlock(&ssl_lock);
-#endif
+  MUTEX_UNLOCK(&ssl_lock);
 #endif
 }
 
@@ -146,9 +152,7 @@ void mailstream_ssl_init_not_required(void)
 static inline void mailstream_ssl_init(void)
 {
 #ifdef USE_SSL
-#ifdef LIBETPAN_REENTRANT
-  pthread_mutex_lock(&ssl_lock);
-#endif
+  MUTEX_LOCK(&ssl_lock);
 #ifndef USE_GNUTLS
   if (!openssl_init_done) {
     SSL_library_init();
@@ -160,9 +164,7 @@ static inline void mailstream_ssl_init(void)
     gnutls_init_done = 1;
   }
 #endif
-#ifdef LIBETPAN_REENTRANT
-  pthread_mutex_unlock(&ssl_lock);
-#endif
+  MUTEX_UNLOCK(&ssl_lock);
 #endif
 }
 
@@ -184,6 +186,31 @@ static inline int mailstream_prepare_fd(int fd)
 }
 #endif
 
+static int wait_SSL_connect(int s, int read)
+{
+  fd_set fds;
+  struct timeval timeout;
+  int r;
+  
+  FD_ZERO(&fds);
+  FD_SET(s, &fds);
+  timeout = mailstream_network_delay;
+  /* TODO: how to cancel this ? */
+  if (read)
+    r = select(s + 1, &fds, NULL, NULL, &timeout);
+  else
+    r = select(s + 1, NULL, &fds, NULL, &timeout);
+  if (r <= 0) {
+    return -1;
+  }
+  
+  if (!FD_ISSET(s, &fds)) {
+    /* though, it's strange */
+    return -1;
+  }
+  
+  return 0;
+}
 
 #ifdef USE_SSL
 static int mailstream_low_ssl_close(mailstream_low * s);
@@ -244,7 +271,25 @@ static struct mailstream_ssl_data * ssl_data_new_full(int fd, SSL_METHOD * metho
   if (SSL_set_fd(ssl_conn, fd) == 0)
     goto free_ssl_conn;
   
+again:
   r = SSL_connect(ssl_conn);
+
+  switch(SSL_get_error(ssl_conn, r)) {
+  	case SSL_ERROR_WANT_READ:
+          r = wait_SSL_connect(fd, 1);
+          if (r < 0)
+            goto free_ssl_conn;
+	  else
+	    goto again;
+	break;
+	case SSL_ERROR_WANT_WRITE:
+          r = wait_SSL_connect(fd, 0);
+          if (r < 0)
+            goto free_ssl_conn;
+	  else
+	    goto again;
+	break;
+  }
   if (r <= 0)
     goto free_ssl_conn;
   
@@ -472,6 +517,11 @@ static int wait_read(mailstream_low * s)
   struct mailstream_ssl_data * ssl_data;
   int max_fd;
   int r;
+  int cancelled;
+  int got_data;
+#ifdef WIN32
+  HANDLE event;
+#endif
   
   ssl_data = (struct mailstream_ssl_data *) s->data;
   timeout = mailstream_network_delay;
@@ -479,6 +529,17 @@ static int wait_read(mailstream_low * s)
   FD_ZERO(&fds_read);
   fd = mailstream_cancel_get_fd(ssl_data->cancel);
   FD_SET(fd, &fds_read);
+#ifdef WIN32
+  event = CreateEvent(NULL, TRUE, FALSE, NULL);
+  WSAEventSelect(ssl_data->fd, event, FD_READ | FD_CLOSE);
+  FD_SET(event, &fds_read);
+  r = WaitForMultipleObjects(fds_read.fd_count, fds_read.fd_array, FALSE, timeout.tv_sec * 1000 + timeout.tv_usec / 1000);
+  if (WAIT_TIMEOUT == r)
+    return -1;
+  
+  cancelled = (fds_read.fd_array[r - WAIT_OBJECT_0] == fd);
+  got_data = (fds_read.fd_array[r - WAIT_OBJECT_0] == event);
+#else
   FD_SET(ssl_data->fd, &fds_read);
   max_fd = ssl_data->fd;
   if (fd > max_fd)
@@ -486,7 +547,11 @@ static int wait_read(mailstream_low * s)
   r = select(max_fd + 1, &fds_read, NULL, NULL, &timeout);
   if (r == 0)
     return -1;
-  if (FD_ISSET(fd, &fds_read)) {
+  
+  cancelled = (FD_ISSET(fd, &fds_read));
+  got_data = FD_ISSET(ssl_data->fd, &fds_read);
+#endif
+  if (cancelled) {
     /* cancelled */
     mailstream_cancel_ack(ssl_data->cancel);
     return -1;
@@ -576,6 +641,11 @@ static int wait_write(mailstream_low * s)
   int fd;
   struct mailstream_ssl_data * ssl_data;
   int max_fd;
+  int cancelled;
+  int write_enabled;
+#ifdef WIN32
+  HANDLE event;
+#endif
   
   ssl_data = (struct mailstream_ssl_data *) s->data;
   if (mailstream_cancel_cancelled(ssl_data->cancel))
@@ -587,6 +657,17 @@ static int wait_write(mailstream_low * s)
   fd = mailstream_cancel_get_fd(ssl_data->cancel);
   FD_SET(fd, &fds_read);
   FD_ZERO(&fds_write);
+#ifdef WIN32
+  event = CreateEvent(NULL, TRUE, FALSE, NULL);
+  WSAEventSelect(ssl_data->fd, event, FD_WRITE | FD_CLOSE);
+  FD_SET(event, &fds_read);
+  r = WaitForMultipleObjects(fds_read.fd_count, fds_read.fd_array, FALSE, timeout.tv_sec * 1000 + timeout.tv_usec / 1000);
+  if (r < 0)
+    return -1;
+  
+  cancelled = (fds_read.fd_array[r - WAIT_OBJECT_0] == fd) /* SEB 20070709 */;
+  write_enabled = (fds_read.fd_array[r - WAIT_OBJECT_0] == event);
+#else
   FD_SET(ssl_data->fd, &fds_write);
   
   max_fd = ssl_data->fd;
@@ -597,13 +678,17 @@ static int wait_write(mailstream_low * s)
   if (r == 0)
     return -1;
   
-  if (FD_ISSET(fd, &fds_read)) {
+  cancelled = FD_ISSET(fd, &fds_read);
+  write_enabled = FD_ISSET(ssl_data->fd, &fds_write);
+#endif
+  
+  if (cancelled) {
     /* cancelled */
     mailstream_cancel_ack(ssl_data->cancel);
     return -1;
   }
   
-  if (!FD_ISSET(ssl_data->fd, &fds_write))
+  if (!write_enabled)
     return 0;
   
   return 1;
@@ -771,21 +856,25 @@ ssize_t mailstream_ssl_get_certificate(mailstream *stream, unsigned char **cert_
 
 static void mailstream_low_ssl_cancel(mailstream_low * s)
 {
+#ifdef USE_SSL
   struct mailstream_ssl_data * data;
   
   data = s->data;
   mailstream_cancel_notify(data->cancel);
+#endif
 }
 
 struct mailstream_ssl_context
 {
   int fd;
+#ifdef USE_SSL
 #ifndef USE_GNUTLS
   SSL_CTX * openssl_ssl_ctx;
 #else
   gnutls_session gnutls_session;
   gnutls_certificate_credentials_t gnutls_credentials;
 #endif
+#endif
 };
 
 mailstream_low * mailstream_low_ssl_open_with_callback(int fd,
@@ -867,3 +956,19 @@ static void mailstream_ssl_context_free(struct mailstream_ssl_context * ssl_ctx)
 }
 #endif
 #endif
+
+void * mailstream_ssl_get_openssl_ssl_ctx(struct mailstream_ssl_context * ssl_context)
+{
+#ifdef USE_SSL
+#ifndef USE_GNUTLS
+  return ssl_context->openssl_ssl_ctx;
+#endif
+#endif /* USE_SSL */
+  return 0;
+}
+
+int mailstream_ssl_get_fd(struct mailstream_ssl_context * ssl_context)
+{
+  return ssl_context->fd;
+}
+
