@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: data_message_driver.c,v 1.10 2006/06/26 11:50:26 hoa Exp $
+ * $Id: data_message_driver.c,v 1.11 2007/01/28 12:54:08 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -66,7 +66,6 @@ static int fetch_size(mailmessage * msg, size_t * result)
 
 
 static mailmessage_driver local_data_message_driver = {
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* msg_name */ "data",
   
   /* msg_initialize */ mailmessage_generic_initialize,
@@ -89,30 +88,6 @@ static mailmessage_driver local_data_message_driver = {
   /* msg_fetch_envelope */ mailmessage_generic_fetch_envelope,
 
   /* msg_get_flags */ NULL,
-#else
-  .msg_name = "data",
-  
-  .msg_initialize = mailmessage_generic_initialize,
-  .msg_uninitialize = mailmessage_generic_uninitialize,
-  
-  .msg_flush = mailmessage_generic_flush,
-  .msg_check = NULL,
-
-  .msg_fetch_result_free = mailmessage_generic_fetch_result_free,
-  
-  .msg_fetch = mailmessage_generic_fetch,
-  .msg_fetch_header = mailmessage_generic_fetch_header,
-  .msg_fetch_body = mailmessage_generic_fetch_body,
-  .msg_fetch_size = fetch_size,
-  .msg_get_bodystructure = mailmessage_generic_get_bodystructure,
-  .msg_fetch_section = mailmessage_generic_fetch_section,
-  .msg_fetch_section_header = mailmessage_generic_fetch_section_header,
-  .msg_fetch_section_mime = mailmessage_generic_fetch_section_mime,
-  .msg_fetch_section_body = mailmessage_generic_fetch_section_body,
-  .msg_fetch_envelope = mailmessage_generic_fetch_envelope,
-
-  .msg_get_flags = NULL,
-#endif
 };
 
 mailmessage_driver * data_message_driver = &local_data_message_driver;
@@ -124,7 +99,8 @@ mailmessage * data_message_init(char * data, size_t len)
   struct generic_message_t * msg_data;
   mailmessage * msg;
   int r;
-
+  struct mailimf_fields * fields;
+  
   msg = mailmessage_new();
   if (msg == NULL)
     goto err;
@@ -138,6 +114,12 @@ mailmessage * data_message_init(char * data, size_t len)
   msg_data->msg_message = data;
   msg_data->msg_length = len;
 
+  r = mailmessage_generic_fetch_envelope(msg, &fields);
+  if (r != MAIL_NO_ERROR)
+    goto free;
+  
+  msg->msg_fields = fields;
+  
   return msg;
 
  free:
