@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver_tools.c,v 1.24 2006/12/13 18:31:31 hoa Exp $
+ * $Id: imapdriver_tools.c,v 1.25 2007/05/19 21:19:50 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1850,7 +1850,7 @@ int imap_add_envelope_fetch_att(struct mailimap_fetch_type * fetch_type)
   }
   
   imap_hdrlist = mailimap_header_list_new(hdrlist);
-  if (imap_hdrlist == 0) {
+  if (imap_hdrlist == NULL) {
     clist_foreach(hdrlist, (clist_func) free, NULL);
     clist_free(hdrlist);
     mailimap_fetch_att_free(fetch_att);
