@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapstorage.c,v 1.17 2006/06/26 11:50:26 hoa Exp $
+ * $Id: imapstorage.c,v 1.18 2007/06/30 12:58:21 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -60,17 +60,10 @@ imap_mailstorage_get_folder_session(struct mailstorage * storage,
 static void imap_mailstorage_uninitialize(struct mailstorage * storage);
 
 static mailstorage_driver imap_mailstorage_driver = {
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sto_name               */ "imap",
   /* sto_connect            */ imap_mailstorage_connect,
   /* sto_get_folder_session */ imap_mailstorage_get_folder_session,
   /* sto_uninitialize       */ imap_mailstorage_uninitialize,
-#else
-  .sto_name               = "imap",
-  .sto_connect            = imap_mailstorage_connect,
-  .sto_get_folder_session = imap_mailstorage_get_folder_session,
-  .sto_uninitialize       = imap_mailstorage_uninitialize,
-#endif
 };
 
 LIBETPAN_EXPORT
@@ -81,10 +74,7 @@ int imap_mailstorage_init(struct mailstorage * storage,
     const char * imap_login, const char * imap_password,
     int imap_cached, const char * imap_cache_directory)
 {
-  struct imap_mailstorage * imap_storage;
-  int r;
-  
-  r = imap_mailstorage_init_sasl(storage,
+  return imap_mailstorage_init_sasl(storage,
       imap_servername, imap_port,
       imap_command,
       imap_connection_type,
@@ -94,15 +84,6 @@ int imap_mailstorage_init(struct mailstorage * storage,
       imap_login, imap_login,
       imap_password, NULL,
       imap_cached, imap_cache_directory);
-  
-  if (r == MAIL_NO_ERROR) {
-    imap_storage = storage->sto_data;
-    imap_storage->imap_auth_type = imap_auth_type;
-    imap_storage->imap_login = imap_storage->imap_sasl.sasl_login;
-    imap_storage->imap_password = imap_storage->imap_sasl.sasl_password;
-  }
-  
-  return r;
 }
 
 LIBETPAN_EXPORT
@@ -117,6 +98,34 @@ int imap_mailstorage_init_sasl(struct mailstorage * storage,
     const char * login, const char * auth_name,
     const char * password, const char * realm,
     int imap_cached, const char * imap_cache_directory)
+{
+  return imap_mailstorage_init_sasl_with_local_address(storage,
+      imap_servername, imap_port,
+      NULL, 0,
+      imap_command,
+      imap_connection_type,
+      auth_type,
+      server_fqdn,
+      local_ip_port,
+      remote_ip_port,
+      login, auth_name,
+      password, realm,
+      imap_cached, imap_cache_directory);
+}
+
+LIBETPAN_EXPORT
+int imap_mailstorage_init_sasl_with_local_address(struct mailstorage * storage,
+    const char * imap_servername, uint16_t imap_port,
+    const char * imap_local_address, uint16_t imap_local_port,
+    const char * imap_command,
+    int imap_connection_type,
+    const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm,
+    int imap_cached, const char * imap_cache_directory)
 {
   struct imap_mailstorage * imap_storage;
 
@@ -124,9 +133,25 @@ int imap_mailstorage_init_sasl(struct mailstorage * storage,
   if (imap_storage == NULL)
     goto err;
 
-  imap_storage->imap_servername = strdup(imap_servername);
-  if (imap_storage->imap_servername == NULL)
-    goto free;
+  if (imap_servername != NULL) {
+    imap_storage->imap_servername = strdup(imap_servername);
+    if (imap_storage->imap_servername == NULL)
+      goto free;
+  }
+  else {
+    imap_storage->imap_servername = NULL;
+  }
+
+  if (imap_local_address != NULL) {
+    imap_storage->imap_local_address = strdup(imap_local_address);
+    if (imap_storage->imap_local_address == NULL)
+      goto free_servername;
+  }
+  else {
+    imap_storage->imap_local_address = NULL;
+  }
+  
+  imap_storage->imap_local_port = imap_local_port;
 
   imap_storage->imap_connection_type = imap_connection_type;
   
@@ -145,6 +170,10 @@ int imap_mailstorage_init_sasl(struct mailstorage * storage,
     case CONNECTION_TYPE_COMMAND_TLS:
       imap_port = IMAPS_DEFAULT_PORT;
       break;
+
+    default:
+      imap_port = IMAP_DEFAULT_PORT;
+      break;
     }
   }
 
@@ -153,7 +182,7 @@ int imap_mailstorage_init_sasl(struct mailstorage * storage,
   if (imap_command != NULL) {
     imap_storage->imap_command = strdup(imap_command);
     if (imap_storage->imap_command == NULL)
-      goto free_servername;
+      goto free_local_address;
   }
   else
     imap_storage->imap_command = NULL;
@@ -237,12 +266,31 @@ int imap_mailstorage_init_sasl(struct mailstorage * storage,
     imap_storage->imap_cached = FALSE;
     imap_storage->imap_cache_directory = NULL;
   }
-
+  
+  imap_storage->imap_auth_type = imap_storage->imap_auth_type;
+  if (imap_storage->imap_sasl.sasl_login != NULL) {
+    imap_storage->imap_login = strdup(imap_storage->imap_sasl.sasl_login);
+    if (imap_storage->imap_login == NULL)
+      goto free_cache_directory;
+  }
+  else {
+    imap_storage->imap_login = NULL;
+  }
+  if (imap_storage->imap_sasl.sasl_password != NULL) {
+    imap_storage->imap_password = strdup(imap_storage->imap_sasl.sasl_password);
+    if (imap_storage->imap_password == NULL)
+      goto free_copy_login;
+  }
+  
   storage->sto_data = imap_storage;
   storage->sto_driver = &imap_mailstorage_driver;
 
   return MAIL_NO_ERROR;
 
+ free_copy_login:
+  free(imap_storage->imap_login);
+ free_cache_directory:
+  free(imap_storage->imap_cache_directory);
  free_realm:
   free(imap_storage->imap_sasl.sasl_realm);
  free_password:
@@ -261,6 +309,8 @@ int imap_mailstorage_init_sasl(struct mailstorage * storage,
   free(imap_storage->imap_sasl.sasl_auth_type);
  free_command:
   free(imap_storage->imap_command);
+ free_local_address:
+  free(imap_storage->imap_local_address);
  free_servername:
   free(imap_storage->imap_servername);
  free:
@@ -272,11 +322,13 @@ int imap_mailstorage_init_sasl(struct mailstorage * storage,
 static void imap_mailstorage_uninitialize(struct mailstorage * storage)
 {
   struct imap_mailstorage * imap_storage;
-
+  
   imap_storage = storage->sto_data;
-
-  if (imap_storage->imap_cache_directory != NULL)
-    free(imap_storage->imap_cache_directory);
+  
+  free(imap_storage->imap_password);
+  free(imap_storage->imap_login);
+  
+  free(imap_storage->imap_cache_directory);
   
   free(imap_storage->imap_sasl.sasl_realm);
   free(imap_storage->imap_sasl.sasl_password);
@@ -287,8 +339,8 @@ static void imap_mailstorage_uninitialize(struct mailstorage * storage)
   free(imap_storage->imap_sasl.sasl_server_fqdn);
   free(imap_storage->imap_sasl.sasl_auth_type);
   
-  if (imap_storage->imap_command != NULL)
-    free(imap_storage->imap_command);
+  free(imap_storage->imap_command);
+  free(imap_storage->imap_local_address);
   free(imap_storage->imap_servername);
   free(imap_storage);
   
@@ -311,9 +363,11 @@ static int imap_connect(struct mailstorage * storage,
   else
     driver = imap_session_driver;
   
-  r = mailstorage_generic_connect(driver,
+  r = mailstorage_generic_connect_with_local_address(driver,
       imap_storage->imap_servername,
       imap_storage->imap_port,
+      imap_storage->imap_local_address,
+      imap_storage->imap_local_port,
       imap_storage->imap_command,
       imap_storage->imap_connection_type,
       IMAPDRIVER_CACHED_SET_CACHE_DIRECTORY,
@@ -330,23 +384,15 @@ static int imap_connect(struct mailstorage * storage,
     goto err;
   }
 
-  if (imap_storage->imap_sasl.sasl_enabled) {
-    r = mailstorage_generic_auth_sasl(session, r,
-        imap_storage->imap_sasl.sasl_auth_type,
-        imap_storage->imap_sasl.sasl_server_fqdn,
-        imap_storage->imap_sasl.sasl_local_ip_port,
-        imap_storage->imap_sasl.sasl_remote_ip_port,
-        imap_storage->imap_sasl.sasl_login,
-        imap_storage->imap_sasl.sasl_auth_name,
-        imap_storage->imap_sasl.sasl_password,
-        imap_storage->imap_sasl.sasl_realm);
-  }
-  else {
-    r = mailstorage_generic_auth(session, r,
-        imap_storage->imap_auth_type,
-        imap_storage->imap_sasl.sasl_login,
-        imap_storage->imap_sasl.sasl_password);
-  }
+  r = mailstorage_generic_auth_sasl(session, r,
+      imap_storage->imap_sasl.sasl_auth_type,
+      imap_storage->imap_sasl.sasl_server_fqdn,
+      imap_storage->imap_sasl.sasl_local_ip_port,
+      imap_storage->imap_sasl.sasl_remote_ip_port,
+      imap_storage->imap_sasl.sasl_login,
+      imap_storage->imap_sasl.sasl_auth_name,
+      imap_storage->imap_sasl.sasl_password,
+      imap_storage->imap_sasl.sasl_realm);
   if (r != MAIL_NO_ERROR) {
     res = r;
     goto free;
