@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maildirdriver.c,v 1.12 2005/08/15 11:08:40 hoa Exp $
+ * $Id: maildirdriver.c,v 1.15 2006/06/28 06:13:47 skunk Exp $
  */
 
 
@@ -39,6 +39,10 @@
   than standards
 */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "maildirdriver.h"
 
 #include <stdio.h>
@@ -67,30 +71,30 @@ static int initialize(mailsession * session);
 
 static void uninitialize(mailsession * session);
 
-static int connect_path(mailsession * session, char * path);
+static int connect_path(mailsession * session, const char * path);
 
 static int logout(mailsession * session);
 
 static int expunge_folder(mailsession * session);
 
-static int status_folder(mailsession * session, char * mb,
+static int status_folder(mailsession * session, const char * mb,
     uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen);
 
-static int recent_number(mailsession * session, char * mb,
+static int recent_number(mailsession * session, const char * mb,
     uint32_t * result);
 
-static int unseen_number(mailsession * session, char * mb,
+static int unseen_number(mailsession * session, const char * mb,
     uint32_t * result);
 
-static int messages_number(mailsession * session, char * mb,
+static int messages_number(mailsession * session, const char * mb,
     uint32_t * result);
 
 static int append_message(mailsession * session,
-    char * message, size_t size);
+    const char * message, size_t size);
 
 static int append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags);
+    const char * message, size_t size, struct mail_flags * flags);
 
 static int get_messages_list(mailsession * session,
     struct mailmessage_list ** result);
@@ -105,7 +109,7 @@ static int get_message_by_uid(mailsession * session,
 
 static mailsession_driver local_maildir_session_driver = {
 
-#if defined (_MSC_VER) || defined (__SUNPRO_CC)
+#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
 	
    /* sess_name */ "maildir",
 
@@ -265,7 +269,7 @@ static void uninitialize(mailsession * session)
 }
 
 
-static int connect_path(mailsession * session, char * path)
+static int connect_path(mailsession * session, const char * path)
 {
   struct maildir * md;
   int res;
@@ -316,7 +320,7 @@ static int logout(mailsession * session)
 
 /* folders operations */
 
-static int status_folder(mailsession * session, char * mb,
+static int status_folder(mailsession * session, const char * mb,
     uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen)
 {
@@ -358,7 +362,7 @@ static int status_folder(mailsession * session, char * mb,
   return MAIL_NO_ERROR;
 }
 
-static int messages_number(mailsession * session, char * mb,
+static int messages_number(mailsession * session, const char * mb,
     uint32_t * result)
 {
   struct maildir * md;
@@ -377,7 +381,7 @@ static int messages_number(mailsession * session, char * mb,
   return MAIL_NO_ERROR;
 }
 
-static int unseen_number(mailsession * session, char * mb,
+static int unseen_number(mailsession * session, const char * mb,
     uint32_t * result)
 {
   uint32_t messages;
@@ -394,7 +398,7 @@ static int unseen_number(mailsession * session, char * mb,
   return MAIL_NO_ERROR;
 }
 
-static int recent_number(mailsession * session, char * mb,
+static int recent_number(mailsession * session, const char * mb,
     uint32_t * result)
 {
   uint32_t messages;
@@ -415,7 +419,7 @@ static int recent_number(mailsession * session, char * mb,
 /* messages operations */
 
 static int append_message(mailsession * session,
-    char * message, size_t size)
+    const char * message, size_t size)
 {
 #if 0
   struct maildir * md;
@@ -436,7 +440,7 @@ static int append_message(mailsession * session,
 }
 
 static int append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags)
+    const char * message, size_t size, struct mail_flags * flags)
 {
   struct maildir * md;
   int r;
