@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mboxstorage.h,v 1.7 2005/06/01 12:21:58 smarinier Exp $
+ * $Id: mboxstorage.h,v 1.8 2006/06/02 15:44:29 smarinier Exp $
  */
 
 #ifndef MBOXSTORAGE_H
@@ -60,8 +60,8 @@ extern "C" {
 
 LIBETPAN_EXPORT
 int mbox_mailstorage_init(struct mailstorage * storage,
-    char * mb_pathname, int mb_cached,
-    char * mb_cache_directory, char * mb_flags_directory);
+    const char * mb_pathname, int mb_cached,
+    const char * mb_cache_directory, const char * mb_flags_directory);
 
 #ifdef __cplusplus
 }
