@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: nntpstorage.c,v 1.16 2006/06/26 11:50:27 hoa Exp $
+ * $Id: nntpstorage.c,v 1.18 2007/06/30 23:35:25 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -59,26 +59,40 @@ static int nntp_mailstorage_get_folder_session(struct mailstorage * storage,
 static void nntp_mailstorage_uninitialize(struct mailstorage * storage);
 
 static mailstorage_driver nntp_mailstorage_driver = {
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sto_name               */ "nntp",
   /* sto_connect            */ nntp_mailstorage_connect,
   /* sto_get_folder_session */ nntp_mailstorage_get_folder_session,
   /* sto_uninitialize       */ nntp_mailstorage_uninitialize,
-#else
-  .sto_name               = "nntp",
-  .sto_connect            = nntp_mailstorage_connect,
-  .sto_get_folder_session = nntp_mailstorage_get_folder_session,
-  .sto_uninitialize       = nntp_mailstorage_uninitialize,
-#endif
 };
 
 LIBETPAN_EXPORT
 int nntp_mailstorage_init(struct mailstorage * storage,
-    const char * nn_servername, uint16_t nn_port,
-    const char * nn_command,
-    int nn_connection_type, int nn_auth_type,
-    const char * nn_login, const char * nn_password,
-    int nn_cached, const char * nn_cache_directory, const char * nn_flags_directory)
+    const char * nntp_servername, uint16_t nntp_port,
+    const char * nntp_command,
+    int nntp_connection_type, int nntp_auth_type,
+    const char * nntp_login, const char * nntp_password,
+    int nntp_cached,
+    const char * nntp_cache_directory, const char * nntp_flags_directory)
+{
+  return nntp_mailstorage_init_with_local_address(storage,
+    nntp_servername, nntp_port,
+    NULL, 0,
+    nntp_command,
+    nntp_connection_type, nntp_auth_type,
+    nntp_login, nntp_password,
+    nntp_cached, nntp_cache_directory,
+    nntp_flags_directory);
+}
+
+LIBETPAN_EXPORT
+int nntp_mailstorage_init_with_local_address(struct mailstorage * storage,
+    const char * nntp_servername, uint16_t nntp_port,
+    const char * nntp_local_address, uint16_t nntp_local_port,
+    const char * nntp_command,
+    int nntp_connection_type, int nntp_auth_type,
+    const char * nntp_login, const char * nntp_password,
+    int nntp_cached, const char * nntp_cache_directory,
+    const char * nntp_flags_directory)
 {
   struct nntp_mailstorage * nntp_storage;
   int res;
@@ -88,49 +102,67 @@ int nntp_mailstorage_init(struct mailstorage * storage,
     res = MAIL_ERROR_MEMORY;
     goto err;
   }
-
-  nntp_storage->nntp_servername = strdup(nn_servername);
-  if (nntp_storage->nntp_servername == NULL) {
-    res = MAIL_ERROR_MEMORY;
-    goto free;
+  
+  if (nntp_servername != NULL) {
+    nntp_storage->nntp_servername = strdup(nntp_servername);
+    if (nntp_storage->nntp_servername == NULL) {
+      res = MAIL_ERROR_MEMORY;
+      goto free;
+    }
+  }
+  else {
+    nntp_storage->nntp_servername = NULL;
+  }
+  
+  if (nntp_local_address != NULL) {
+    nntp_storage->nntp_local_address = strdup(nntp_local_address);
+    if (nntp_storage->nntp_local_address == NULL) {
+      res = MAIL_ERROR_MEMORY;
+      goto free_servername;
+    }
+  }
+  else {
+    nntp_storage->nntp_local_address = NULL;
   }
 
-  nntp_storage->nntp_connection_type = nn_connection_type;
+  nntp_storage->nntp_local_port = nntp_local_port;
+
+  nntp_storage->nntp_connection_type = nntp_connection_type;
   
-  if (nn_port == 0) {
-    switch (nn_connection_type) {
+  if (nntp_port == 0) {
+    switch (nntp_connection_type) {
     case CONNECTION_TYPE_PLAIN:
     case CONNECTION_TYPE_COMMAND:
-      nn_port = NNTP_DEFAULT_PORT;
+      nntp_port = NNTP_DEFAULT_PORT;
       break;
 
     case CONNECTION_TYPE_TLS:
     case CONNECTION_TYPE_COMMAND_TLS:
-      nn_port = NNTPS_DEFAULT_PORT;
+      nntp_port = NNTPS_DEFAULT_PORT;
       break;
     
     default:
-      res = MAIL_ERROR_INVAL;
-      goto free_servername;
+      nntp_port = NNTP_DEFAULT_PORT;
+      break;
     }
   }
 
-  nntp_storage->nntp_port = nn_port;
+  nntp_storage->nntp_port = nntp_port;
 
-  if (nn_command != NULL) {
-    nntp_storage->nntp_command = strdup(nn_command);
+  if (nntp_command != NULL) {
+    nntp_storage->nntp_command = strdup(nntp_command);
     if (nntp_storage->nntp_command == NULL) {
       res = MAIL_ERROR_MEMORY;
-      goto free_servername;
+      goto free_local_address;
     }
   }
   else
     nntp_storage->nntp_command = NULL;
 
-  nntp_storage->nntp_auth_type = nn_auth_type;
+  nntp_storage->nntp_auth_type = nntp_auth_type;
 
-  if (nn_login != NULL) {
-    nntp_storage->nntp_login = strdup(nn_login);
+  if (nntp_login != NULL) {
+    nntp_storage->nntp_login = strdup(nntp_login);
     if (nntp_storage->nntp_login == NULL) {
       res = MAIL_ERROR_MEMORY;
       goto free_command;
@@ -139,8 +171,8 @@ int nntp_mailstorage_init(struct mailstorage * storage,
   else
     nntp_storage->nntp_login = NULL;
 
-  if (nn_password != NULL) {
-    nntp_storage->nntp_password = strdup(nn_password);
+  if (nntp_password != NULL) {
+    nntp_storage->nntp_password = strdup(nntp_password);
     if (nntp_storage->nntp_password == NULL) {
       res = MAIL_ERROR_MEMORY;
       goto free_login;
@@ -149,16 +181,16 @@ int nntp_mailstorage_init(struct mailstorage * storage,
   else
     nntp_storage->nntp_password = NULL;
 
-  nntp_storage->nntp_cached = nn_cached;
-
-  if (nn_cached && (nn_cache_directory != NULL) &&
-      (nn_flags_directory != NULL)) {
-    nntp_storage->nntp_cache_directory = strdup(nn_cache_directory);
+  nntp_storage->nntp_cached = nntp_cached;
+  
+  if (nntp_cached && (nntp_cache_directory != NULL) &&
+      (nntp_flags_directory != NULL)) {
+    nntp_storage->nntp_cache_directory = strdup(nntp_cache_directory);
     if (nntp_storage->nntp_cache_directory == NULL) {
       res = MAIL_ERROR_MEMORY;
       goto free_password;
     }
-    nntp_storage->nntp_flags_directory = strdup(nn_flags_directory);
+    nntp_storage->nntp_flags_directory = strdup(nntp_flags_directory);
     if (nntp_storage->nntp_flags_directory == NULL) {
       res = MAIL_ERROR_MEMORY;
       goto free_cache_directory;
@@ -169,7 +201,7 @@ int nntp_mailstorage_init(struct mailstorage * storage,
     nntp_storage->nntp_cache_directory = NULL;
     nntp_storage->nntp_flags_directory = NULL;
   }
-
+  
   storage->sto_data = nntp_storage;
   storage->sto_driver = &nntp_mailstorage_driver;
 
@@ -183,6 +215,8 @@ int nntp_mailstorage_init(struct mailstorage * storage,
   free(nntp_storage->nntp_login);
  free_command:
   free(nntp_storage->nntp_command);
+ free_local_address:
+  free(nntp_storage->nntp_local_address);
  free_servername:
   free(nntp_storage->nntp_servername);
  free:
@@ -194,19 +228,15 @@ int nntp_mailstorage_init(struct mailstorage * storage,
 static void nntp_mailstorage_uninitialize(struct mailstorage * storage)
 {
   struct nntp_mailstorage * nntp_storage;
-
+  
   nntp_storage = storage->sto_data;
-
-  if (nntp_storage->nntp_flags_directory != NULL)
-    free(nntp_storage->nntp_flags_directory);
-  if (nntp_storage->nntp_cache_directory != NULL)
-    free(nntp_storage->nntp_cache_directory);
-  if (nntp_storage->nntp_password != NULL)
-    free(nntp_storage->nntp_password);
-  if (nntp_storage->nntp_login != NULL)
-    free(nntp_storage->nntp_login);
-  if (nntp_storage->nntp_command != NULL)
-    free(nntp_storage->nntp_command);
+  
+  free(nntp_storage->nntp_flags_directory);
+  free(nntp_storage->nntp_cache_directory);
+  free(nntp_storage->nntp_password);
+  free(nntp_storage->nntp_login);
+  free(nntp_storage->nntp_command);
+  free(nntp_storage->nntp_local_address);
   free(nntp_storage->nntp_servername);
   free(nntp_storage);
   
@@ -228,9 +258,10 @@ static int nntp_mailstorage_connect(struct mailstorage * storage)
   else
     driver = nntp_session_driver;
 
-  r = mailstorage_generic_connect(driver,
-      nntp_storage->nntp_servername,
-      nntp_storage->nntp_port, nntp_storage->nntp_command,
+  r = mailstorage_generic_connect_with_local_address(driver,
+      nntp_storage->nntp_servername, nntp_storage->nntp_port,
+      nntp_storage->nntp_local_address, nntp_storage->nntp_local_port,
+      nntp_storage->nntp_command,
       nntp_storage->nntp_connection_type,
       NNTPDRIVER_CACHED_SET_CACHE_DIRECTORY,
       nntp_storage->nntp_cache_directory,
