@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: pop3storage.c,v 1.17 2006/06/26 11:50:27 hoa Exp $
+ * $Id: pop3storage.c,v 1.19 2007/06/30 23:35:25 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -57,17 +57,10 @@ static int pop3_mailstorage_get_folder_session(struct mailstorage * storage,
 static void pop3_mailstorage_uninitialize(struct mailstorage * storage);
 
 static mailstorage_driver pop3_mailstorage_driver = {
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sto_name               */ "pop3",
   /* sto_connect            */ pop3_mailstorage_connect,
   /* sto_get_folder_session */ pop3_mailstorage_get_folder_session,
   /* sto_uninitialize       */ pop3_mailstorage_uninitialize,
-#else
-  .sto_name               = "pop3",
-  .sto_connect            = pop3_mailstorage_connect,
-  .sto_get_folder_session = pop3_mailstorage_get_folder_session,
-  .sto_uninitialize       = pop3_mailstorage_uninitialize,
-#endif
 };
 
 LIBETPAN_EXPORT
@@ -76,31 +69,32 @@ int pop3_mailstorage_init(struct mailstorage * storage,
     const char * pop3_command,
     int pop3_connection_type, int pop3_auth_type,
     const char * pop3_login, const char * pop3_password,
-    int pop3_cached, const char * pop3_cache_directory, const char * pop3_flags_directory)
+    int pop3_cached,
+    const char * pop3_cache_directory, const char * pop3_flags_directory)
 {
-  struct pop3_mailstorage * pop3_storage;
-  int r;
+  char * sasl_auth_type;
   
-  r =  pop3_mailstorage_init_sasl(storage,
+  sasl_auth_type = NULL;
+  switch (pop3_auth_type) {
+  case POP3_AUTH_TYPE_APOP:
+    sasl_auth_type = POP3_SASL_AUTH_TYPE_APOP;
+    break;
+  case POP3_AUTH_TYPE_TRY_APOP:
+    sasl_auth_type = POP3_SASL_AUTH_TYPE_TRY_APOP;
+    break;
+  }
+  
+  return pop3_mailstorage_init_sasl(storage,
       pop3_servername, pop3_port,
       pop3_command,
       pop3_connection_type,
-      NULL,
+      sasl_auth_type,
       NULL,
       NULL, NULL,
       pop3_login, pop3_login,
       pop3_password, NULL,
       pop3_cached, pop3_cache_directory,
       pop3_flags_directory);
-  
-  if (r == MAIL_NO_ERROR) {
-    pop3_storage = storage->sto_data;
-    pop3_storage->pop3_auth_type = pop3_auth_type;
-    pop3_storage->pop3_login = pop3_storage->pop3_sasl.sasl_login;
-    pop3_storage->pop3_password = pop3_storage->pop3_sasl.sasl_password;
-  }
-  
-  return r;
 }
 
 LIBETPAN_EXPORT
@@ -116,6 +110,36 @@ int pop3_mailstorage_init_sasl(struct mailstorage * storage,
     const char * password, const char * realm,
     int pop3_cached, const char * pop3_cache_directory,
     const char * pop3_flags_directory)
+{
+  return pop3_mailstorage_init_sasl_with_local_address(storage,
+      pop3_servername, pop3_port,
+      NULL, 0,
+      pop3_command,
+      pop3_connection_type,
+      auth_type,
+      server_fqdn,
+      local_ip_port,
+      remote_ip_port,
+      login, auth_name,
+      password, realm,
+      pop3_cached, pop3_cache_directory,
+      pop3_flags_directory);
+}
+
+LIBETPAN_EXPORT
+int pop3_mailstorage_init_sasl_with_local_address(struct mailstorage * storage,
+    const char * pop3_servername, uint16_t pop3_port,
+    const char * pop3_local_address, uint16_t pop3_local_port,
+    const char * pop3_command,
+    int pop3_connection_type,
+    const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm,
+    int pop3_cached, const char * pop3_cache_directory,
+    const char * pop3_flags_directory)
 {
   struct pop3_mailstorage * pop3_storage;
 
@@ -123,10 +147,26 @@ int pop3_mailstorage_init_sasl(struct mailstorage * storage,
   if (pop3_storage == NULL)
     goto err;
   
-  pop3_storage->pop3_servername = strdup(pop3_servername);
-  if (pop3_storage->pop3_servername == NULL)
-    goto free;
+  if (pop3_servername != NULL) {
+    pop3_storage->pop3_servername = strdup(pop3_servername);
+    if (pop3_storage->pop3_servername == NULL)
+      goto free;
+  }
+  else {
+    pop3_storage->pop3_servername = NULL;
+  }
 
+  if (pop3_local_address != NULL) {
+    pop3_storage->pop3_local_address = strdup(pop3_local_address);
+    if (pop3_storage->pop3_local_address == NULL)
+      goto free_servername;
+  }
+  else {
+    pop3_storage->pop3_local_address = NULL;
+  }
+  
+  pop3_storage->pop3_local_port = pop3_local_port;
+  
   pop3_storage->pop3_connection_type = pop3_connection_type;
   
   if (pop3_port == 0) {
@@ -144,6 +184,10 @@ int pop3_mailstorage_init_sasl(struct mailstorage * storage,
     case CONNECTION_TYPE_COMMAND_TLS:
       pop3_port = POP3S_DEFAULT_PORT;
       break;
+
+    default:
+      pop3_port = POP3_DEFAULT_PORT;
+      break;
     }
   }
 
@@ -152,7 +196,7 @@ int pop3_mailstorage_init_sasl(struct mailstorage * storage,
   if (pop3_command != NULL) {
     pop3_storage->pop3_command = strdup(pop3_command);
     if (pop3_storage->pop3_command == NULL)
-      goto free_servername;
+      goto free_local_address;
   }
   else
     pop3_storage->pop3_command = NULL;
@@ -161,6 +205,17 @@ int pop3_mailstorage_init_sasl(struct mailstorage * storage,
   
   pop3_storage->pop3_sasl.sasl_enabled = (auth_type != NULL);
   
+  if (auth_type != NULL) {
+    if (strcmp(auth_type, POP3_SASL_AUTH_TYPE_APOP) == 0) {
+      pop3_storage->pop3_auth_type = POP3_AUTH_TYPE_APOP;
+      auth_type = NULL;
+    }
+    else if (strcmp(auth_type, POP3_SASL_AUTH_TYPE_APOP) == 0) {
+      pop3_storage->pop3_auth_type = POP3_AUTH_TYPE_TRY_APOP;
+      auth_type = NULL;
+    }
+  }
+  
   if (auth_type != NULL) {
     pop3_storage->pop3_sasl.sasl_auth_type = strdup(auth_type);
     if (pop3_storage->pop3_sasl.sasl_auth_type == NULL)
@@ -242,11 +297,28 @@ int pop3_mailstorage_init_sasl(struct mailstorage * storage,
     pop3_storage->pop3_flags_directory = NULL;
   }
 
+  pop3_storage->pop3_auth_type = pop3_storage->pop3_auth_type;
+  if (pop3_storage->pop3_sasl.sasl_login != NULL) {
+    pop3_storage->pop3_login = strdup(pop3_storage->pop3_sasl.sasl_login);
+    if (pop3_storage->pop3_login == NULL)
+      goto free_cache_directory;
+  }
+  else {
+    pop3_storage->pop3_login = NULL;
+  }
+  if (pop3_storage->pop3_sasl.sasl_password != NULL) {
+    pop3_storage->pop3_password = strdup(pop3_storage->pop3_sasl.sasl_password);
+    if (pop3_storage->pop3_password == NULL)
+      goto free_copy_login;
+  }
+  
   storage->sto_data = pop3_storage;
   storage->sto_driver = &pop3_mailstorage_driver;
-
+  
   return MAIL_NO_ERROR;
-
+  
+ free_copy_login:
+  free(pop3_storage->pop3_login);
  free_cache_directory:
   free(pop3_storage->pop3_cache_directory);
  free_realm:
@@ -266,11 +338,11 @@ int pop3_mailstorage_init_sasl(struct mailstorage * storage,
  free_auth_type:
   free(pop3_storage->pop3_sasl.sasl_auth_type);
  free_command:
-  if (pop3_storage->pop3_command != NULL)
-    free(pop3_storage->pop3_command);
+  free(pop3_storage->pop3_command);
+ free_local_address:
+  free(pop3_storage->pop3_local_address);
  free_servername:
-  if (pop3_storage->pop3_servername != NULL)
-    free(pop3_storage->pop3_servername);
+  free(pop3_storage->pop3_servername);
  free:
   free(pop3_storage);
  err:
@@ -280,14 +352,15 @@ int pop3_mailstorage_init_sasl(struct mailstorage * storage,
 static void pop3_mailstorage_uninitialize(struct mailstorage * storage)
 {
   struct pop3_mailstorage * pop3_storage;
-
+  
   pop3_storage = storage->sto_data;
-
-  if (pop3_storage->pop3_flags_directory != NULL)
-    free(pop3_storage->pop3_flags_directory);
-  if (pop3_storage->pop3_cache_directory != NULL)
-    free(pop3_storage->pop3_cache_directory);
-
+  
+  free(pop3_storage->pop3_password);
+  free(pop3_storage->pop3_login);
+  
+  free(pop3_storage->pop3_flags_directory);
+  free(pop3_storage->pop3_cache_directory);
+  
   free(pop3_storage->pop3_sasl.sasl_realm);
   free(pop3_storage->pop3_sasl.sasl_password);
   free(pop3_storage->pop3_sasl.sasl_auth_name);
@@ -297,8 +370,8 @@ static void pop3_mailstorage_uninitialize(struct mailstorage * storage)
   free(pop3_storage->pop3_sasl.sasl_server_fqdn);
   free(pop3_storage->pop3_sasl.sasl_auth_type);
   
-  if (pop3_storage->pop3_command != NULL)
-    free(pop3_storage->pop3_command);
+  free(pop3_storage->pop3_command);
+  free(pop3_storage->pop3_local_address);
   free(pop3_storage->pop3_servername);
   free(pop3_storage);
   
@@ -321,9 +394,12 @@ static int pop3_mailstorage_connect(struct mailstorage * storage)
   else
     driver = pop3_session_driver;
 
-  r = mailstorage_generic_connect(driver,
+  r = mailstorage_generic_connect_with_local_address(driver,
       pop3_storage->pop3_servername,
-      pop3_storage->pop3_port, pop3_storage->pop3_command,
+      pop3_storage->pop3_port,
+      pop3_storage->pop3_local_address,
+      pop3_storage->pop3_local_port,
+      pop3_storage->pop3_command,
       pop3_storage->pop3_connection_type,
       POP3DRIVER_CACHED_SET_CACHE_DIRECTORY,
       pop3_storage->pop3_cache_directory,
@@ -356,24 +432,16 @@ static int pop3_mailstorage_connect(struct mailstorage * storage)
   if (auth_type != -1) {
     mailsession_parameters(session, POP3DRIVER_SET_AUTH_TYPE, &auth_type);
   }
-
-  if (pop3_storage->pop3_sasl.sasl_enabled) {
-    r = mailstorage_generic_auth_sasl(session, r,
-        pop3_storage->pop3_sasl.sasl_auth_type,
-        pop3_storage->pop3_sasl.sasl_server_fqdn,
-        pop3_storage->pop3_sasl.sasl_local_ip_port,
-        pop3_storage->pop3_sasl.sasl_remote_ip_port,
-        pop3_storage->pop3_sasl.sasl_login,
-        pop3_storage->pop3_sasl.sasl_auth_name,
-        pop3_storage->pop3_sasl.sasl_password,
-        pop3_storage->pop3_sasl.sasl_realm);
-  }
-  else {
-    r = mailstorage_generic_auth(session, r,
-        pop3_storage->pop3_auth_type,
-        pop3_storage->pop3_sasl.sasl_login,
-        pop3_storage->pop3_sasl.sasl_password);
-  }
+  
+  r = mailstorage_generic_auth_sasl(session, r,
+      pop3_storage->pop3_sasl.sasl_auth_type,
+      pop3_storage->pop3_sasl.sasl_server_fqdn,
+      pop3_storage->pop3_sasl.sasl_local_ip_port,
+      pop3_storage->pop3_sasl.sasl_remote_ip_port,
+      pop3_storage->pop3_sasl.sasl_login,
+      pop3_storage->pop3_sasl.sasl_auth_name,
+      pop3_storage->pop3_sasl.sasl_password,
+      pop3_storage->pop3_sasl.sasl_realm);
   if (r != MAIL_NO_ERROR) {
     if (pop3_storage->pop3_auth_type == POP3_AUTH_TYPE_TRY_APOP) {
       /* try in clear authentication */
@@ -381,11 +449,11 @@ static int pop3_mailstorage_connect(struct mailstorage * storage)
       
       pop3_storage->pop3_auth_type = POP3_AUTH_TYPE_PLAIN;
       r = mailstorage_connect(storage);
+      pop3_storage->pop3_auth_type = POP3_AUTH_TYPE_TRY_APOP;
       if (r != MAIL_NO_ERROR) {
         res = r;
         return res;
       }
-      pop3_storage->pop3_auth_type = POP3_AUTH_TYPE_TRY_APOP;
       
       return MAIL_NO_ERROR;
     }
