@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mailmessage.c,v 1.16 2005/06/01 12:22:00 smarinier Exp $
+ * $Id: mailmessage.c,v 1.17 2006/05/22 13:39:40 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailmessage.h"
 
 #include "mail.h"
