@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mailstorage.c,v 1.22 2005/06/01 12:22:00 smarinier Exp $
+ * $Id: mailstorage.c,v 1.24 2006/06/02 15:44:30 smarinier Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailstorage.h"
 
 #include "maildriver.h"
@@ -45,7 +49,7 @@ static int mailstorage_get_folder(struct mailstorage * storage,
 
 LIBETPAN_EXPORT
 struct mailfolder * mailfolder_new(struct mailstorage * storage,
-    char * pathname, char * virtual_name)
+    const char * pathname, const char * virtual_name)
 {
   struct mailfolder * folder;
   
@@ -242,7 +246,7 @@ int mailfolder_detach_parent(struct mailfolder * folder)
 }
 
 LIBETPAN_EXPORT
-struct mailstorage * mailstorage_new(char * sto_id)
+struct mailstorage * mailstorage_new(const char * sto_id)
 {
   struct mailstorage * storage;
 
