@@ -70,7 +70,7 @@ int mailimap_acl_setacl(mailimap * session,
   if (session->imap_state != MAILIMAP_STATE_AUTHENTICATED)
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -86,10 +86,10 @@ int mailimap_acl_setacl(mailimap * session,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -118,7 +118,7 @@ int mailimap_acl_deleteacl(mailimap * session,
   if (session->imap_state != MAILIMAP_STATE_AUTHENTICATED)
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -134,10 +134,10 @@ int mailimap_acl_deleteacl(mailimap * session,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -168,7 +168,7 @@ int mailimap_acl_getacl(mailimap * session,
   if (session->imap_state != MAILIMAP_STATE_AUTHENTICATED)
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -184,10 +184,10 @@ int mailimap_acl_getacl(mailimap * session,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -244,7 +244,7 @@ int mailimap_acl_listrights(mailimap * session,
   if (session->imap_state != MAILIMAP_STATE_AUTHENTICATED)
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -260,10 +260,10 @@ int mailimap_acl_listrights(mailimap * session,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -320,7 +320,7 @@ int mailimap_acl_myrights(mailimap * session,
   if (session->imap_state != MAILIMAP_STATE_AUTHENTICATED)
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -335,10 +335,10 @@ int mailimap_acl_myrights(mailimap * session,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
