@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap.c,v 1.38 2006/12/10 10:02:50 colinleroy Exp $
+ * $Id: mailimap.c,v 1.41 2007/05/25 01:31:18 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -543,7 +543,7 @@ int mailimap_connect(mailimap * session, mailstream * s)
   if (connection_info != NULL)
     session->imap_connection_info = connection_info;
 
-  if (read_line(session) == NULL) {
+  if (mailimap_read_line(session) == NULL) {
     return MAILIMAP_ERROR_STREAM;
   }
 
@@ -594,7 +594,7 @@ int mailimap_append(mailimap * session, const char * mailbox,
       (session->imap_state != MAILIMAP_STATE_SELECTED))
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
 	return r;
   
@@ -608,7 +608,7 @@ int mailimap_append(mailimap * session, const char * mailbox,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
   index = 0;
@@ -621,7 +621,7 @@ int mailimap_append(mailimap * session, const char * mailbox,
     mailimap_continue_req_free(cont_req);
 
   if (r == MAILIMAP_ERROR_PARSE) {
-    r = parse_response(session, &response);
+    r = mailimap_parse_response(session, &response);
     if (r != MAILIMAP_NO_ERROR)
       return r;
     mailimap_response_free(response);
@@ -641,10 +641,10 @@ int mailimap_append(mailimap * session, const char * mailbox,
   if (mailstream_flush(session->imap_stream) == -1)
 	return MAILIMAP_ERROR_STREAM;
 	
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -668,7 +668,7 @@ int mailimap_noop(mailimap * session)
   int r;
   int error_code;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
 	return r;
 
@@ -683,10 +683,10 @@ int mailimap_noop(mailimap * session)
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -711,7 +711,7 @@ int mailimap_logout(mailimap * session)
   int error_code;
   int res;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR) {
     res = r;
     goto close;
@@ -734,12 +734,12 @@ int mailimap_logout(mailimap * session)
     goto close;
   }
 
-  if (read_line(session) == NULL) {
+  if (mailimap_read_line(session) == NULL) {
     res = MAILIMAP_ERROR_STREAM;
     goto close;
   }
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR) {
     res = r;
     goto close;
@@ -862,7 +862,7 @@ int mailimap_capability(mailimap * session,
   int error_code;
   struct mailimap_capability_data * cap_data;
   
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
 	return r;
 
@@ -877,10 +877,10 @@ int mailimap_capability(mailimap * session,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
   
@@ -914,7 +914,7 @@ int mailimap_check(mailimap * session)
   if (session->imap_state != MAILIMAP_STATE_SELECTED)
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
 	return r;
 
@@ -929,10 +929,10 @@ int mailimap_check(mailimap * session)
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -959,7 +959,7 @@ int mailimap_close(mailimap * session)
   if (session->imap_state != MAILIMAP_STATE_SELECTED)
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
 	return r;
 
@@ -974,10 +974,10 @@ int mailimap_close(mailimap * session)
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1009,7 +1009,7 @@ int mailimap_expunge(mailimap * session)
   if (session->imap_state != MAILIMAP_STATE_SELECTED)
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
 	return r;
 
@@ -1024,10 +1024,10 @@ int mailimap_expunge(mailimap * session)
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1055,7 +1055,7 @@ int mailimap_copy(mailimap * session, struct mailimap_set * set,
   if (session->imap_state != MAILIMAP_STATE_SELECTED)
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1070,10 +1070,10 @@ int mailimap_copy(mailimap * session, struct mailimap_set * set,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1101,7 +1101,7 @@ int mailimap_uid_copy(mailimap * session, struct mailimap_set * set,
   if (session->imap_state != MAILIMAP_STATE_SELECTED)
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1116,10 +1116,10 @@ int mailimap_uid_copy(mailimap * session, struct mailimap_set * set,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1147,7 +1147,7 @@ int mailimap_create(mailimap * session, const char * mb)
       (session->imap_state != MAILIMAP_STATE_SELECTED))
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1162,10 +1162,10 @@ int mailimap_create(mailimap * session, const char * mb)
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1194,7 +1194,7 @@ int mailimap_delete(mailimap * session, const char * mb)
       (session->imap_state != MAILIMAP_STATE_SELECTED))
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1209,10 +1209,10 @@ int mailimap_delete(mailimap * session, const char * mb)
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1240,7 +1240,7 @@ int mailimap_examine(mailimap * session, const char * mb)
       (session->imap_state != MAILIMAP_STATE_SELECTED))
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1255,14 +1255,14 @@ int mailimap_examine(mailimap * session, const char * mb)
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
   if (session->imap_selection_info != NULL)
     mailimap_selection_info_free(session->imap_selection_info);
   session->imap_selection_info = mailimap_selection_info_new();
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1295,7 +1295,7 @@ mailimap_fetch(mailimap * session, struct mailimap_set * set,
   if (session->imap_state != MAILIMAP_STATE_SELECTED)
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1310,10 +1310,10 @@ mailimap_fetch(mailimap * session, struct mailimap_set * set,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1353,7 +1353,7 @@ mailimap_uid_fetch(mailimap * session,
   if (session->imap_state != MAILIMAP_STATE_SELECTED)
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1368,10 +1368,10 @@ mailimap_uid_fetch(mailimap * session,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   
   if (r != MAILIMAP_NO_ERROR)
     return r;
@@ -1404,7 +1404,7 @@ int mailimap_list(mailimap * session, const char * mb,
       (session->imap_state != MAILIMAP_STATE_SELECTED))
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1419,10 +1419,10 @@ int mailimap_list(mailimap * session, const char * mb,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1453,7 +1453,7 @@ int mailimap_login(mailimap * session,
   if (session->imap_state != MAILIMAP_STATE_NON_AUTHENTICATED)
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1468,10 +1468,10 @@ int mailimap_login(mailimap * session,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1635,7 +1635,7 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
     goto free_sasl_conn;
   }
   
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR) {
     res = r;
     goto free_sasl_conn;
@@ -1666,7 +1666,7 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
     unsigned int encoded_len;
     unsigned int max_encoded;
     
-    if (read_line(session) == NULL) {
+    if (mailimap_read_line(session) == NULL) {
       res = MAILIMAP_ERROR_STREAM;
       goto free_sasl_conn;
     }
@@ -1770,7 +1770,7 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
   free(session->imap_sasl.sasl_secret);
   session->imap_sasl.sasl_secret = NULL;
   
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR) {
     res = r;
     goto free_sasl_conn;
@@ -1818,7 +1818,7 @@ int mailimap_lsub(mailimap * session, const char * mb,
       (session->imap_state != MAILIMAP_STATE_SELECTED))
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
 	return r;
 
@@ -1833,10 +1833,10 @@ int mailimap_lsub(mailimap * session, const char * mb,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1875,7 +1875,7 @@ int mailimap_rename(mailimap * session,
       (session->imap_state != MAILIMAP_STATE_SELECTED))
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
 	return r;
 
@@ -1890,10 +1890,10 @@ int mailimap_rename(mailimap * session,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1922,7 +1922,7 @@ mailimap_search(mailimap * session, const char * charset,
   if (session->imap_state != MAILIMAP_STATE_SELECTED)
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
 	return r;
 
@@ -1937,10 +1937,10 @@ mailimap_search(mailimap * session, const char * charset,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1972,7 +1972,7 @@ mailimap_uid_search(mailimap * session, const char * charset,
   if (session->imap_state != MAILIMAP_STATE_SELECTED)
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -1987,10 +1987,10 @@ mailimap_uid_search(mailimap * session, const char * charset,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -2029,7 +2029,7 @@ mailimap_select(mailimap * session, const char * mb)
       (session->imap_state != MAILIMAP_STATE_SELECTED))
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -2044,14 +2044,14 @@ mailimap_select(mailimap * session, const char * mb)
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
   if (session->imap_selection_info != NULL)
     mailimap_selection_info_free(session->imap_selection_info);
   session->imap_selection_info = mailimap_selection_info_new();
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -2086,7 +2086,7 @@ mailimap_status(mailimap * session, const char * mb,
       (session->imap_state != MAILIMAP_STATE_SELECTED))
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
 	return r;
 
@@ -2101,10 +2101,10 @@ mailimap_status(mailimap * session, const char * mb,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -2138,7 +2138,7 @@ mailimap_store(mailimap * session,
   if (session->imap_state != MAILIMAP_STATE_SELECTED)
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -2153,10 +2153,10 @@ mailimap_store(mailimap * session,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -2186,7 +2186,7 @@ mailimap_uid_store(mailimap * session,
   if (session->imap_state != MAILIMAP_STATE_SELECTED)
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
 	return r;
 
@@ -2201,10 +2201,10 @@ mailimap_uid_store(mailimap * session,
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -2232,7 +2232,7 @@ int mailimap_subscribe(mailimap * session, const char * mb)
       (session->imap_state != MAILIMAP_STATE_SELECTED))
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
 	return r;
 
@@ -2247,10 +2247,10 @@ int mailimap_subscribe(mailimap * session, const char * mb)
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -2278,7 +2278,7 @@ int mailimap_unsubscribe(mailimap * session, const char * mb)
       (session->imap_state != MAILIMAP_STATE_SELECTED))
     return MAILIMAP_ERROR_BAD_STATE;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -2293,10 +2293,10 @@ int mailimap_unsubscribe(mailimap * session, const char * mb)
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -2321,7 +2321,7 @@ int mailimap_starttls(mailimap * session)
   int r;
   int error_code;
 
-  r = send_current_tag(session);
+  r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -2336,10 +2336,10 @@ int mailimap_starttls(mailimap * session)
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
 
-  if (read_line(session) == NULL)
+  if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  r = parse_response(session, &response);
+  r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -2358,12 +2358,12 @@ int mailimap_starttls(mailimap * session)
 
 
 
-char * read_line(mailimap * session)
+char * mailimap_read_line(mailimap * session)
 {
   return mailstream_read_line(session->imap_stream, session->imap_stream_buffer);
 }
 
-int send_current_tag(mailimap * session)
+int mailimap_send_current_tag(mailimap * session)
 {
   char tag_str[15];
   int r;
@@ -2382,8 +2382,8 @@ int send_current_tag(mailimap * session)
   return MAILIMAP_NO_ERROR;
 }
 
-int parse_response(mailimap * session,
-	 			struct mailimap_response ** result)
+int mailimap_parse_response(mailimap * session,
+    struct mailimap_response ** result)
 {
   size_t index;
   struct mailimap_response * response;
@@ -2458,19 +2458,23 @@ static int parse_greeting(mailimap * session,
   greeting_store(session, greeting);
 
   if (greeting->gr_type == MAILIMAP_GREETING_RESP_COND_BYE) {
-    if (mmap_string_assign(session->imap_response_buffer,
-            greeting->gr_data.gr_bye->rsp_text->rsp_text) == NULL)
-      return MAILIMAP_ERROR_MEMORY;
+    if (greeting->gr_data.gr_bye->rsp_text->rsp_text != NULL) {
+      if (mmap_string_assign(session->imap_response_buffer,
+              greeting->gr_data.gr_bye->rsp_text->rsp_text) == NULL)
+        return MAILIMAP_ERROR_MEMORY;
+    }
 
     session->imap_response = session->imap_response_buffer->str;
     
     return MAILIMAP_ERROR_DONT_ACCEPT_CONNECTION;
   }
-
-  if (mmap_string_assign(session->imap_response_buffer,
-          greeting->gr_data.gr_auth->rsp_text->rsp_text) == NULL)
-    return MAILIMAP_ERROR_MEMORY;
-
+  
+  if (greeting->gr_data.gr_auth->rsp_text->rsp_text != NULL) {
+    if (mmap_string_assign(session->imap_response_buffer,
+            greeting->gr_data.gr_auth->rsp_text->rsp_text) == NULL)
+      return MAILIMAP_ERROR_MEMORY;
+  }
+  
   session->imap_response = session->imap_response_buffer->str;
 
   * result = greeting;
@@ -2515,8 +2519,11 @@ mailimap * mailimap_new(size_t imap_progr_rate,
   f->imap_sasl.sasl_conn = NULL;
 #endif
   
+  f->imap_idle_timestamp = 0;
+  f->imap_idle_maxdelay = 29 * 60; /* IMAP IDLE spec */
+  
   return f;
-
+  
  free_stream_buffer:
   mmap_string_free(f->imap_stream_buffer);
  free_f:
