@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimf.h,v 1.24 2005/06/01 12:22:01 smarinier Exp $
+ * $Id: mailimf.h,v 1.25 2006/05/22 13:39:42 hoa Exp $
  */
 
 #ifndef MAILIMF_H
@@ -47,10 +47,10 @@ extern "C" {
 #include <libetpan/mailimf_write_mem.h>
 #include <libetpan/mailimf_types_helper.h>
 
-#if HAVE_INTTYPES_H
+#ifdef HAVE_INTTYPES_H
 #	include <inttypes.h>
 #endif
-#if HAVE_SYS_TYPES_H
+#ifdef HAVE_SYS_TYPES_H
 #	include <sys/types.h>
 #endif
 
