@@ -46,6 +46,7 @@
 #endif
 
 #include "mailimf.h"
+#include "timeutils.h"
 
 struct mailimf_mailbox_list *
 mailimf_mailbox_list_new_empty(void)
@@ -1284,28 +1285,28 @@ char * mailimf_get_message_id(void)
   return strdup(id);
 }
 
-
-
-static time_t mkgmtime(struct tm * tmp);
-
-
 struct mailimf_date_time * mailimf_get_current_date(void)
+{
+  time_t now;
+
+  now = time(NULL);
+  return mailimf_get_date(now);
+}
+
+struct mailimf_date_time * mailimf_get_date(time_t time)
 {
   struct tm gmt;
   struct tm lt;
   int off;
-  time_t now;
   struct mailimf_date_time * date_time;
 
-  now = time(NULL);
-
-  if (gmtime_r(&now, &gmt) == NULL)
+  if (gmtime_r(&time, &gmt) == NULL)
     return NULL;
 
-  if (localtime_r(&now, &lt) == NULL)
+  if (localtime_r(&time, &lt) == NULL)
     return NULL;
 
-  off = (mkgmtime(&lt) - mkgmtime(&gmt)) / (60 * 60) * 100;
+  off = (mail_mkgmtime(&lt) - mail_mkgmtime(&gmt)) / (60 * 60) * 100;
 
   date_time = mailimf_date_time_new(lt.tm_mday, lt.tm_mon + 1, lt.tm_year + 1900,
 				    lt.tm_hour, lt.tm_min, lt.tm_sec,
@@ -1314,165 +1315,6 @@ struct mailimf_date_time * mailimf_get_current_date(void)
   return date_time;
 }
 
-
-
-/* mkgmtime.c - make time corresponding to a GMT timeval struct
- $Id: mailimf_types_helper.c,v 1.18 2006/10/22 20:22:06 hoa Exp $
- 
- * Copyright (c) 1998-2000 Carnegie Mellon University.  All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The name "Carnegie Mellon University" must not be used to
- *    endorse or promote products derived from this software without
- *    prior written permission. For permission or any other legal
- *    details, please contact  
- *      Office of Technology Transfer
- *      Carnegie Mellon University
- *      5000 Forbes Avenue
- *      Pittsburgh, PA  15213-3890
- *      (412) 268-4387, fax: (412) 268-7395
- *      tech-transfer@andrew.cmu.edu
- *
- * 4. Redistributions of any form whatsoever must retain the following
- *    acknowledgment:
- *    "This product includes software developed by Computing Services
- *     at Carnegie Mellon University (http://www.cmu.edu/computing/)."
- *
- * CARNEGIE MELLON UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO
- * THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS, IN NO EVENT SHALL CARNEGIE MELLON UNIVERSITY BE LIABLE
- * FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
- * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
- * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
- * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
- *
- *
- */
-/*
- * Copyright (c) 1987, 1989, 1993
- *	The Regents of the University of California.  All rights reserved.
- *
- * This code is derived from software contributed to Berkeley by
- * Arthur David Olson of the National Cancer Institute.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
- *    may be used to endorse or promote products derived from this software
- *    without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
- * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
- * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- */
-
-/*
-** Adapted from code provided by Robert Elz, who writes:
-**	The "best" way to do mktime I think is based on an idea of Bob
-**	Kridle's (so its said...) from a long time ago. (mtxinu!kridle now).
-**	It does a binary search of the time_t space.  Since time_t's are
-**	just 32 bits, its a max of 32 iterations (even at 64 bits it
-**	would still be very reasonable).
-*/
-
-/*
-  adapted for libEtPan! by DINH V. Hoa
-*/
-
-#ifndef WRONG
-#define WRONG	(-1)
-#endif /* !defined WRONG */
-
-static int tmcomp(struct tm * atmp, struct tm * btmp)
-{
-  register int	result;
-  
-  if ((result = (atmp->tm_year - btmp->tm_year)) == 0 &&
-      (result = (atmp->tm_mon - btmp->tm_mon)) == 0 &&
-      (result = (atmp->tm_mday - btmp->tm_mday)) == 0 &&
-      (result = (atmp->tm_hour - btmp->tm_hour)) == 0 &&
-      (result = (atmp->tm_min - btmp->tm_min)) == 0)
-    result = atmp->tm_sec - btmp->tm_sec;
-  return result;
-}
-
-static time_t mkgmtime(struct tm * tmp)
-{
-  register int			dir;
-  register int			bits;
-  register int			saved_seconds;
-  time_t				t;
-  struct tm			yourtm, *mytm;
-  
-  yourtm = *tmp;
-  saved_seconds = yourtm.tm_sec;
-  yourtm.tm_sec = 0;
-  /*
-  ** Calculate the number of magnitude bits in a time_t
-  ** (this works regardless of whether time_t is
-  ** signed or unsigned, though lint complains if unsigned).
-  */
-  for (bits = 0, t = 1; t > 0; ++bits, t <<= 1)
-    ;
-  /*
-  ** If time_t is signed, then 0 is the median value,
-  ** if time_t is unsigned, then 1 << bits is median.
-  */
-  t = (t < 0) ? 0 : ((time_t) 1 << bits);
-  for ( ; ; ) {
-    mytm = gmtime(&t);
-    dir = tmcomp(mytm, &yourtm);
-    if (dir != 0) {
-      if (bits-- < 0)
-	return WRONG;
-      if (bits < 0)
-	--t;
-      else if (dir > 0)
-	t -= (time_t) 1 << bits;
-      else	t += (time_t) 1 << bits;
-      continue;
-    }
-    break;
-  }
-  t += saved_seconds;
-  return t;
-}
-
-
-
-
-
-
-
 void mailimf_single_fields_init(struct mailimf_single_fields * single_fields,
                                 struct mailimf_fields * fields)
 {
