@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: newsnntp.c,v 1.23 2005/06/01 16:04:46 hoa Exp $
+ * $Id: newsnntp.c,v 1.26 2007/06/29 23:09:51 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "newsnntp.h"
 
 
@@ -347,6 +351,20 @@ int newsnntp_article(newsnntp * f, uint32_t index, char ** result,
   return newsnntp_get_content(f, result, result_len);
 }
 
+int newsnntp_article_by_message_id(newsnntp * f, char * msg_id,
+    char ** result, size_t * result_len)
+{
+  char command[NNTP_STRING_SIZE];
+  int r;
+
+  snprintf(command, NNTP_STRING_SIZE, "ARTICLE <%s>\r\n", msg_id);
+  r = send_command(f, command);
+  if (r == -1)
+    return NEWSNNTP_ERROR_STREAM;
+
+  return newsnntp_get_content(f, result, result_len);
+}
+
 /* ******************** BODY ******************************** */
 
 int newsnntp_body(newsnntp * f, uint32_t index, char ** result,
