@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: newsnntp.h,v 1.19 2006/05/22 13:39:42 hoa Exp $
+ * $Id: newsnntp.h,v 1.20 2007/06/28 23:24:20 hoa Exp $
  */
 
 #ifndef NEWSNNTP_H
@@ -61,12 +61,14 @@ void newsnntp_free(newsnntp * f);
 int newsnntp_quit(newsnntp * f);
 int newsnntp_connect(newsnntp * f, mailstream * s);
 
-int newsnntp_head(newsnntp * f, uint32_t index, char ** result,
-		  size_t * result_len);
-int newsnntp_article(newsnntp * f, uint32_t index, char ** result,
-		     size_t * result_len);
-int newsnntp_body(newsnntp * f, uint32_t index, char ** result,
-		  size_t * result_len);
+int newsnntp_head(newsnntp * f, uint32_t index,
+    char ** result, size_t * result_len);
+int newsnntp_article(newsnntp * f, uint32_t index,
+    char ** result, size_t * result_len);
+int newsnntp_article_by_message_id(newsnntp * f, char * msg_id,
+    char ** result, size_t * result_len);
+int newsnntp_body(newsnntp * f, uint32_t index,
+    char ** result, size_t * result_len);
 
 void newsnntp_head_free(char * str);
 void newsnntp_article_free(char * str);
