@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailpop3.c,v 1.29 2006/12/22 18:45:44 hoa Exp $
+ * $Id: mailpop3.c,v 1.30 2007/07/21 18:44:40 hoa Exp $
  */
 
 /*
@@ -1461,6 +1461,16 @@ int mailpop3_auth(mailpop3 * f, const char * auth_type,
           got_response = 0;
         
         if (got_response) {
+          char * p;
+          
+          p = strchr(f->pop3_response, '\r');
+          if (p != NULL) {
+            * p = '\0';
+          }
+          p = strchr(f->pop3_response, '\n');
+          if (p != NULL) {
+            * p = '\0';
+          }
           response_len = strlen(f->pop3_response);
           max_decoded = response_len * 3 / 4;
           decoded = malloc(max_decoded + 1);
