@@ -30,18 +30,22 @@
  */
 
 /*
- * $Id: mailpop3_socket.c,v 1.11 2005/06/01 12:22:20 smarinier Exp $
+ * $Id: mailpop3_socket.c,v 1.14 2006/12/26 13:13:24 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailpop3_socket.h"
 
 #include "mailpop3.h"
 
 #include "connect.h"
-#if HAVE_NETINET_IN_H
+#ifdef HAVE_NETINET_IN_H
 #	include <netinet/in.h>
 #endif
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
 
@@ -58,9 +62,8 @@ int mailpop3_socket_connect(mailpop3 * f, const char * server, uint16_t port)
     port = mail_get_service_port(SERVICE_NAME_POP3, SERVICE_TYPE_TCP);
     if (port == 0)
       port = DEFAULT_POP3_PORT;
-    port = ntohs(port);
   }
-
+  
   /* Connection */
 
   s = mail_tcp_connect(server, port);
@@ -75,3 +78,43 @@ int mailpop3_socket_connect(mailpop3 * f, const char * server, uint16_t port)
 
   return mailpop3_connect(f, stream);
 }
+
+LIBETPAN_EXPORT
+int mailpop3_socket_starttls(mailpop3 * f)
+{
+  return mailpop3_socket_starttls_with_callback(f, NULL, NULL);
+}
+
+LIBETPAN_EXPORT
+int mailpop3_socket_starttls_with_callback(mailpop3 * f,
+    void (* callback)(struct mailstream_ssl_context * ssl_context, void * data), void * data)
+{
+  int r;
+  int fd;
+  mailstream_low * low;
+  mailstream_low * new_low;
+  
+  r = mailpop3_stls(f);
+
+  switch (r) {
+  case MAILPOP3_NO_ERROR:
+    break;
+  default:
+    return r;
+  }
+
+  low = mailstream_get_low(f->pop3_stream);
+  fd = mailstream_low_get_fd(low);
+  if (fd == -1)
+    return MAILPOP3_ERROR_STREAM;
+  
+  new_low = mailstream_low_tls_open_with_callback(fd,
+      callback, data);
+  if (new_low == NULL)
+    return MAILPOP3_ERROR_SSL;
+  
+  mailstream_low_free(low);
+  mailstream_set_low(f->pop3_stream, new_low);
+  
+  return MAILPOP3_NO_ERROR;
+}
