@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailpop3_ssl.c,v 1.13 2006/05/22 13:39:42 hoa Exp $
+ * $Id: mailpop3_ssl.c,v 1.15 2006/12/26 13:13:24 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -54,6 +54,13 @@
 #define SERVICE_TYPE_TCP "tcp"
 
 int mailpop3_ssl_connect(mailpop3 * f, const char * server, uint16_t port)
+{
+  return mailpop3_ssl_connect_with_callback(f, server, port,
+      NULL, NULL);
+}
+
+int mailpop3_ssl_connect_with_callback(mailpop3 * f, const char * server, uint16_t port,
+    void (* callback)(struct mailstream_ssl_context * ssl_context, void * data), void * data)
 {
   int s;
   mailstream * stream;
@@ -70,10 +77,10 @@ int mailpop3_ssl_connect(mailpop3 * f, const char * server, uint16_t port)
   if (s == -1)
     return MAILPOP3_ERROR_CONNECTION_REFUSED;
 
-  stream = mailstream_ssl_open(s);
+  stream = mailstream_ssl_open_with_callback(s, callback, data);
   if (stream == NULL) {
     close(s);
-    return MAILPOP3_ERROR_CONNECTION_REFUSED;
+    return MAILPOP3_ERROR_SSL;
   }
 
   return mailpop3_connect(f, stream);
