@@ -32,7 +32,7 @@
  */
 
 /*
- * $Id: mailsmtp.c,v 1.28 2006/12/13 18:31:33 hoa Exp $
+ * $Id: mailsmtp.c,v 1.31 2007/07/26 23:14:02 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -636,6 +636,7 @@ int auth_map_errors(int err)
   }
 }
 
+#if 0
 static int mailsmtp_auth_login(mailsmtp * session,
     const char * user, const char * pass)
 {
@@ -684,175 +685,11 @@ static int mailsmtp_auth_login(mailsmtp * session,
   
   return err;
 }
-
-#if 0
-static int mailsmtp_auth_plain(mailsmtp * session,
-    const char * user, const char * pass)
-{
-  int err, len;
-  char command[SMTP_STRING_SIZE];
-  char * plain, * plain64;
-
-  len = strlen(user) + strlen(pass) + 3;
-  plain = (char *) malloc(len);
-  if (plain == NULL) {
-    err = MAILSMTP_ERROR_MEMORY;
-    goto err;
-  }
-  
-  snprintf(plain, len, "%c%s%c%s", '\0', user, '\0', pass);
-  plain64 = encode_base64(plain, len - 1);
-
-  snprintf(command, SMTP_STRING_SIZE, "%s\r\n", plain64);
-  err = send_command(session, command);
-  if (err == -1) {
-    err = MAILSMTP_ERROR_STREAM;
-    goto err_free;
-  }
-
-  err = read_response(session);
-  err = auth_map_errors(err);
-  
-err_free:
-  free(plain64);
-  free(plain);
-
- err:
-  return err;
-}
-
-static char * convert_hex(unsigned char *in, int len)
-{
-  static char hex[] = "0123456789abcdef";
-  char * out;
-  int i;
-
-  out = (char *) malloc(len * 2 + 1);
-  if (out == NULL)
-    return NULL;
-
-  for (i = 0; i < len; i++) {
-    out[i * 2] = hex[in[i] >> 4];
-    out[i * 2 + 1] = hex[in[i] & 15];
-  }
-
-  out[i*2] = 0;
-  
-  return out;
-}
-
-static char * hash_md5(const char * sec_key, const char * data, int len)
-{
-  char key[65], digest[24];
-  char * hash_hex;
-  
-  int sec_len, i;
-
-  sec_len = strlen(sec_key);
-  
-  if (sec_len < 64) {
-    memcpy(key, sec_key, sec_len);      
-    for (i = sec_len; i < 64; i++) {
-      key[i] = 0;
-    }
-  } else {
-    memcpy(key, sec_key, 64);      
-  }
-
-  hmac_md5(data, len, key, 64, digest);
-  hash_hex = convert_hex((unsigned char *) digest, 16);
-
-  return hash_hex;
-}
-
-static int mailsmtp_auth_cram_md5(mailsmtp * session,
-    const char * user, const char * pass)
-{
-  int err;
-  char command[SMTP_STRING_SIZE];
-  char *response, *auth_hex, *auth;
-  
-  response = decode_base64(session->response, strlen(session->response));
-  if (response == NULL) return MAILSMTP_ERROR_MEMORY;
-  
-  auth_hex = hash_md5(pass, response, strlen(response));
-  if (auth_hex == NULL) {
-    err = MAILSMTP_ERROR_MEMORY;
-    goto err_free_response;
-  }
-  
-  snprintf(command, SMTP_STRING_SIZE, "%s %s", user, auth_hex);
-  
-  auth = encode_base64(command, strlen(command));
-  if (auth == NULL) {
-    err = MAILSMTP_ERROR_MEMORY;
-    goto err_free_auth_hex;
-  }
-
-  snprintf(command, SMTP_STRING_SIZE, "%s\r\n", auth);
-  err = send_command(session, command);
-  if (err == -1) {
-    err = MAILSMTP_ERROR_STREAM;
-    goto err_free;
-  }
-
-  err = read_response(session);
-  err = auth_map_errors(err);
-  
-err_free:  
-  free(auth);
-err_free_auth_hex:
-  free(auth_hex);
-err_free_response:
-  free(response);
-  return err;
-}
 #endif
 
 int mailsmtp_auth_type(mailsmtp * session,
     const char * user, const char * pass, int type)
 {
-#if 0 /* deprecated */
-  int err;
-  char command[SMTP_STRING_SIZE];
-  
-  if (session->auth == MAILSMTP_AUTH_NOT_CHECKED) 
-    return MAILSMTP_ERROR_BAD_SEQUENCE_OF_COMMAND;
-    
-  if ( !(session->auth & type) ) return MAILSMTP_ERROR_AUTH_NOT_SUPPORTED;
-  
-  switch (type) {
-  case MAILSMTP_AUTH_LOGIN:
-    snprintf(command, SMTP_STRING_SIZE, "AUTH LOGIN\r\n");
-    break;
-  case MAILSMTP_AUTH_PLAIN:
-    snprintf(command, SMTP_STRING_SIZE, "AUTH PLAIN\r\n");
-    break;
-  case MAILSMTP_AUTH_CRAM_MD5:
-    snprintf(command, SMTP_STRING_SIZE, "AUTH CRAM-MD5\r\n");
-    break;
-  default:
-    return MAILSMTP_ERROR_NOT_IMPLEMENTED;
-  }
-  
-  err = send_command(session, command);
-  if (err == -1) return MAILSMTP_ERROR_STREAM;
-
-  err = read_response(session);
-  err = auth_map_errors(err);
-  if (err != MAILSMTP_NO_ERROR) return err;
-  
-  switch (type) {
-  case MAILSMTP_AUTH_LOGIN:
-    return mailsmtp_auth_login(session, user, pass);
-  case MAILSMTP_AUTH_PLAIN:
-    return mailsmtp_auth_plain(session, user, pass);
-  case MAILSMTP_AUTH_CRAM_MD5:
-    return mailsmtp_auth_cram_md5(session, user, pass);
-  default:
-    return MAILSMTP_ERROR_NOT_IMPLEMENTED;
-  }
-#endif
   int err;
   char command[SMTP_STRING_SIZE];
   char hostname[SMTP_STRING_SIZE];
@@ -869,6 +706,7 @@ int mailsmtp_auth_type(mailsmtp * session,
   
   switch (type) {
   case MAILSMTP_AUTH_LOGIN:
+#if 0
     {
       snprintf(command, SMTP_STRING_SIZE, "AUTH LOGIN\r\n");
       err = send_command(session, command);
@@ -880,6 +718,10 @@ int mailsmtp_auth_type(mailsmtp * session,
       
       return mailsmtp_auth_login(session, user, pass);
     }
+#endif
+    return mailesmtp_auth_sasl(session, "LOGIN",
+        hostname, NULL, NULL, user, user, pass, NULL);
+    
   case MAILSMTP_AUTH_PLAIN:
     return mailesmtp_auth_sasl(session, "PLAIN",
         hostname, NULL, NULL, user, user, pass, NULL);
@@ -1255,6 +1097,16 @@ int mailesmtp_auth_sasl(mailsmtp * session, const char * auth_type,
         char * decoded;
         unsigned int decoded_len;
         unsigned int max_decoded;
+        char * p;
+        
+        p = strchr(session->response, '\r');
+        if (p != NULL) {
+          * p = '\0';
+        }
+        p = strchr(session->response, '\n');
+        if (p != NULL) {
+          * p = '\0';
+        }
         
         response_len = strlen(session->response);
         max_decoded = response_len * 3 / 4;
