@@ -1,8 +1,9 @@
-#if HAVE_UNISTD_H
-#	include <unistd.h>
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
 #endif
 #include <string.h>
 #include <stdlib.h>
+#include <unistd.h>
 
 #include <libetpan/charconv.h>
 #include <libetpan/libetpan.h>
@@ -11,6 +12,8 @@
 #include "readmsg-common.h"
 #ifdef _MSC_VER
 #	include "../src/bsd/getopt.h"
+#else
+#	include <getopt.h>
 #endif
 
 /* render message */
